
export type SameSite = 'Strict' | 'Lax' | 'None';

export function set_cookie(name: string, value: string, expires: Date, secure: boolean, same_site: SameSite = 'Strict', path?: string) {
	const cookie
		= `${name}=${value}; `
		+ `Expires=${expires.toUTCString()}; `
		+ (path ? ` Path=${path}; ` : '')
		+ `HttpOnly; `
		+ `SameSite=${same_site};`
		+ (secure ? ' Secure;' : '')
		;

	return cookie;
}

export function invalidate_cookie(name: string, secure: boolean, path?: string) {
	return set_cookie(name, 'invalidate', new Date(0), secure, 'Strict', path);
}

export function parse_req_cookies(cookies: string) : Record<string, string> {
	const result: Record<string, string> = { };

	if (! cookies) {
		return result;
	}

	for (const cookie of cookies.split(';')) {
		const index = cookie.indexOf('=');
		
		if (index < 0) {
			continue;
		}

		const name = cookie.slice(0, index).trim();
		const value = cookie.slice(index + 1).trim();

		result[name] = decodeURIComponent(value);
	}

	return result;
}
